==> kadu_1.3.orig.tar.bz2: kadu-1.3/plugins/emoticons/translations/emoticons_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="pl" version="2.0">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>domyślny</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Emotikony</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Włącz emotikony</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Animuj emotikony</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Zestaw emotikon</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Wybierz zestaw emotikon</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Zainstaluj nowe emotikony...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Otwórz plik ze schematem emotikon</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Instalacja się nie powiodła</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Archiwum (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Wstaw emotikonę</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Wstaw emotikonę</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Wstaw emotikonę - włącz w konfiguracji</translation>
    </message>
</context>
</TS>

==> kadu_3.0~rc1.orig.tar.bz2: kadu-3.0-rc1/plugins/emoticons/translations/emoticons_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>@default</name>
    <message>
        <source>default</source>
        <translation>domyślny</translation>
    </message>
    <message>
        <source>Look</source>
        <translation>Wygląd</translation>
    </message>
    <message>
        <source>Icons</source>
        <translation>Ikony</translation>
    </message>
    <message>
        <source>Emoticons</source>
        <translation>Emotikony</translation>
    </message>
    <message>
        <source>Enable emoticons</source>
        <translation>Włącz emotikony</translation>
    </message>
    <message>
        <source>Animate emoticons</source>
        <translation>Animuj emotikony</translation>
    </message>
    <message>
        <source>Icon theme</source>
        <translation>Zestaw emotikon</translation>
    </message>
    <message>
        <source>Choose emoticons theme</source>
        <translation>Wybierz zestaw emotikon</translation>
    </message>
    <message>
        <source>Install new emoticons...</source>
        <translation>Zainstaluj nowe emotikony...</translation>
    </message>
</context>
<context>
    <name>EmoticonsConfigurationUiHandler</name>
    <message>
        <source>Open icon theme archive</source>
        <translation>Otwórz plik ze schematem emotikon</translation>
    </message>
    <message>
        <source>Installation failed</source>
        <translation>Instalacja się nie powiodła</translation>
    </message>
    <message>
        <source>Archive (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</source>
        <translation>Archiwum (*.tar.xz *.tar.gz *.tar.bz2 *.tar *.zip)</translation>
    </message>
</context>
<context>
    <name>InsertEmoticonAction</name>
    <message>
        <source>Insert Emoticon</source>
        <translation>Wstaw emotikonę</translation>
    </message>
    <message>
        <source>Insert emoticon</source>
        <translation>Wstaw emotikonę</translation>
    </message>
    <message>
        <source>Insert emoticon - enable in configuration</source>
        <translation>Wstaw emotikonę - włącz w konfiguracji</translation>
    </message>
</context>
</TS>
